@@ -23,7 +23,7 @@
 #' covartype= c("B"),covarpar=list(fargs=c(1),sargs=c(0.5)))
 #' dataa<-simdata$data
 #'
-#' fitbcfrail=bcfraildv(Surv(time,censor)~ X1+frailty(PID) ,data=dataa)
+#' fitbcfrail=bcfrailph(Surv(time,censor)~ X1+frailty(PID) ,data=dataa)
 #' fitbcfrail
 #' summary(fitbcfrail)
 #'
@@ -38,7 +38,7 @@ cat("\nRegression Coefficients:\n")
 zval <- object$coefficients/object$stderr[1:length(object$coefficients)]
 se=object$stderr
 RTAB <- cbind(Estimate =object$coefficients,StdErr =se[1:length(object$coefficients)],
-z.value =  zval,p.value = 2*(1-pnorm(abs(zval), mean=0,sd=1)))
+se2= c(sqrt(diag(object$vcov2))),z.value =  zval,p.value = 2*(1-pnorm(abs(zval), mean=0,sd=1)))
 printCoefmat(RTAB, P.values=TRUE, has.Pvalue=TRUE)
 cat("\nFrailty Distribution:Bivariate Correlated ",object$frailty,"\n")
 if(object$frailty==c("gamma")){
@@ -46,8 +46,8 @@ if(object$frailty==c("gamma")){
   cat("Frailty variance 2 =",object$frailparest[2],"(",se[length(se)-1],")\n")
   cat("Correlation Estimate =",object$frailparest[3],"(",se[length(se)],")\n")}
 if(object$frailty==c("lognormal")){
-  cat("Variance of random effect 1 =",object$frailparest[1],"\n")
-  cat("Variance of random effect 2 =",object$frailparest[2],"\n")
-  cat("Correlation Estimate of random effects =",object$frailparest[3],"\n")}
+  cat("Variance of random effect 1 =",object$frailparest[1],"(",se[length(se)-2],")\n")
+  cat("Variance of random effect 2 =",object$frailparest[2],"(",se[length(se)-1],")\n")
+  cat("Correlation Estimate of random effects =",object$frailparest[3],"(",se[length(se)],")\n")}
 cat("Log likelihood =",object$Iloglilk,"\n")
 }
